'///////////////////////////////////////////////////////////////////////////////////////////
'//
'//                       Firefox Mini Profile Builder V1.0
'//                     for KoXo Profiles & KoXo Administrator
'//                       (C)2006-2013 KoXo Developpement      
'//
'///////////////////////////////////////////////////////////////////////////////////////////
'// Usage :
'// FFConf.vbs 
'//            /StoreFFProfileInMyPath:1 ...
'//            /AlwaysConfigure:1 ... 
'//            /MyPath:"P:\CONFIG\Firefox" ...
'//            /HomePage:"http://mypage" ...
'//            /UseProxy:1 /Proxy:"192.168.1.1" /ProxyPort:"8080" ...
'//            /ProxyNoProxiesOn:"localhost,127.0.0.1" 
'// Example : 
'// FFConf.vbs /MyPath:"P:\Firefox" /StoreFFProfileInMyPath:1 /AlwaysConfigure:1 /HomePage:"http://mypage"
'// --> Save the FF profile in "P:\Firefox", use "http://mypage" as HomePage, and always updates "Prefs.js"
'//
'///////////////////////////////////////////////////////////////////////////////////////////
'//
'/// MAIN ///////////////////////////////////////////////////////////////////////////////////
'//
Dim StoreFFProfileInMyPath,MyPath,AlwaysConfigure,HomePage
Dim UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn
Dim FFProfilePath,FFProfileListDir,FFProfileListFile,FFPrefs
SetDefaultValues()
GetCommandLine()
If StoreFFProfileInMyPath Then
   FFProfilePath=MyPath
   Else
   FFProfilePath=GetRoamingProfilePath & "\Mozilla\Firefox\Profile"
   End If
'Build profile folder
If Not DirectoryExists(FFProfilePath) Then
   ForceDirectories(FFProfilePath)
   End If
'Build FF roaming profile folder if necessary
FFProfileListDir=GetRoamingProfilePath & "\Mozilla\Firefox"
If Not DirectoryExists(FFProfileListDir) Then
   ForceDirectories(FFProfileListDir)
   End If
'Build "profiles.ini" each time
FFProfileListFile=FFProfileListDir & "\profiles.ini"
GenerateFFProfileList(FFProfileListFile)
'Build "prefs.js" or modify it if asked
FFPrefs=FFProfilePath & "\prefs.js"
If Not FileExists(FFPrefs) Then
   GenerateFFPrefs FFPrefs,HomePage,UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn
   Else 
   If AlwaysConfigure Then 
      ModifyFFPrefs FFPrefs,HomePage,UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn
      End If
   End If 
WScript.Quit
'// END MAIN ////////////////////////////////////////////////////////////////////////////////
'//
'///////////////////////////////////////////////////////////////////////////////////////////
'// Set Default values
Function SetDefaultValues()
'StoreFFProfileInMyPath -> 0=roaming profile is use to store FF profile
'                          1=specified folder is used to store FF profile  
StoreFFProfileInMyPath=0      
MyPath="P:\CONFIG\Firefox"
'AlwaysConfigure -> 0=user can modify proxy and homepage settings 
'                   1=proxy and homepage settinfs are configured each time
AlwaysConfigure=1
HomePage="http://www.koxo.net/"
' UseProxy -> -1=do not configure the proxy -0=disable proxy 1=enable the proxy
UseProxy=0                 
Proxy="192.168.1.254"
' ProxyPort-> -1=do not configure the port >-1=configure the port with the value
ProxyPort=8080
ProxyNoProxiesOn="localhost,127.0.0.1,192.168.0.0/24"
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// Command line options
Function GetCommandLine()
Dim S
If WScript.Arguments.Named.Count>0 Then
   S=WScript.Arguments.Named("StoreFFProfileInMyPath")
   If S<>"" Then 
      StoreFFProfileInMyPath=S 
      End If
   S=WScript.Arguments.Named("MyPath")
   If S<>"" Then 
      MyPath=S 
      End If
   S=WScript.Arguments.Named("HomePage")
   If S<>"" Then 
      HomePage=S 
      End If
   S=WScript.Arguments.Named("UseProxy")
   If S<>"" Then 
      UseProxy=S 
      End If
   S=WScript.Arguments.Named("Proxy")
   If S<>"" Then 
      Proxy=S 
      End If
   S=WScript.Arguments.Named("ProxyPort")
   If S<>"" Then 
      ProxyPort=S 
      End If
   S=WScript.Arguments.Named("ProxyNoProxiesOn")
   If S<>"" Then 
      ProxyNoProxiesOn=S 
      End If
   End If
End Function   
'///////////////////////////////////////////////////////////////////////////////////////////
'// Get Roaming Profile Path
Function GetRoamingProfilePath()
 Dim objShell
 Set objShell=CreateObject("WScript.Shell")
 GetRoamingProfilePath=objShell.ExpandEnvironmentStrings("%AppData%")
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// FileExists
Function FileExists(Filename)
Dim objFSO
Set objFSO=CreateObject("Scripting.FileSystemObject")
FileExists=objFSO.FileExists(Filename)
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// DirectoryExists
Function DirectoryExists(Dirname)
Dim objFSO
Set objFSO=CreateObject("Scripting.FileSystemObject")
DirectoryExists=objFSO.FolderExists(Dirname)
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// CreateDirectory
Function CreateDirectory(Dirname)
Dim objFSO
Set objFSO=CreateObject("Scripting.FileSystemObject")
CreateDirectory=objFSO.CreateFolder(Dirname)
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// Generate Firefox Profile List
Function GenerateFFProfileList(Filename)
Dim objFSO,TextFile 
Set objFSO=CreateObject("Scripting.FileSystemObject")
Set TextFile=objFSO.OpenTextFile(Filename,2,True)
TextFile.WriteLine("[General]")
TextFile.WriteLine("StartWithLastProfile=0")
TextFile.WriteLine("")
TextFile.WriteLine("[Profile0]")
TextFile.WriteLine("Name=Firefox")
TextFile.WriteLine("IsRelative=0")
TextFile.WriteLine("Path=" & FFProfilePath)
TextFile.Close
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// Modify a Firefox Prefs
Function ModifyFFPrefs(Filename,HomePage,UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn)
Dim objFSO,TextFile,Contents1,Contents2
Set objFSO=CreateObject("Scripting.FileSystemObject")
Set TextFile=objFSO.OpenTextFile(Filename,1,True)
Contents1=Split(TextFile.ReadAll,vbCrLf)
TextFile.Close
Set TextFile=Nothing 
Contents2=Filter(Contents1,Chr(34)&"browser.startup.homepage"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"browser.shell.checkDefaultBrowser"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"browser.tabs.warnOnClose"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"browser.startup.homepage_override.mstone"&Chr(34),False,vbTextCompare)
'Proxy
Contents2=Filter(Contents2,Chr(34)&"network.proxy.share_proxy_settings"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.type"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.ftp"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.ftp_port"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.http"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.http_port"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.socks"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.socks_port"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.ssl"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.ssl_port"&Chr(34),False,vbTextCompare)
Contents2=Filter(Contents2,Chr(34)&"network.proxy.no_proxies_on"&Chr(34),False,vbTextCompare)
'
Set TextFile=objFSO.OpenTextFile(Filename,2,True)
TextFile.Write Join(Contents2,vbCrLf)
TextFile.Close
GenerateFFPrefs Filename,HomePage,UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// Generate a new Firefox Prefs
Function GenerateFFPrefs(Filename,HomePage,UseProxy,Proxy,ProxyPort,ProxyNoProxiesOn)
Dim objFSO,TextFile,S
Dim ConfString,ConfInteger
Set objFSO=CreateObject("Scripting.FileSystemObject")
Set TextFile=objFSO.OpenTextFile(Filename,8,True)
ConfString="user_pref(##1##, ##2##);"
ConfInteger="user_pref(##1##, #2#);"
S="browser.shell.checkDefaultBrowser" 
S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#","false"),"#",Chr(34))
TextFile.WriteLine(S)
S="browser.tabs.warnOnClose" 
S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#","false"),"#",Chr(34))
TextFile.WriteLine(S)
S="browser.startup.homepage_override.mstone" 
S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#","ignore"),"#",Chr(34))
TextFile.WriteLine(S)
If HomePage<>"" Then 
   S="browser.startup.homepage" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",HomePage),"#",Chr(34))
   TextFile.WriteLine(S)
   End If
If UseProxy>-1 Then 
   S="network.proxy.type" 
   S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#",UseProxy),"#",Chr(34))
   TextFile.WriteLine(S)
   End If
If Proxy<>"" Then 
   S="network.proxy.ftp" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",Proxy),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.http" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",Proxy),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.socks" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",Proxy),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.ssl" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",Proxy),"#",Chr(34))
   TextFile.WriteLine(S)
   End If
If ProxyPort>-1 Then 
   S="network.proxy.ftp_port" 
   S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#",ProxyPort),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.http_port" 
   S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#",ProxyPort),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.socks_port" 
   S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#",ProxyPort),"#",Chr(34))
   TextFile.WriteLine(S)
   S="network.proxy.ssl_port" 
   S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#",ProxyPort),"#",Chr(34))
   TextFile.WriteLine(S)
   End If
If ProxyNoProxiesOn>-1 Then 
   S="network.proxy.no_proxies_on" 
   S=Replace(Replace(Replace(ConfString,"#1#",S),"#2#",ProxyNoProxiesOn),"#",Chr(34))
   TextFile.WriteLine(S)
   End If
S="network.proxy.share_proxy_settings" 
S=Replace(Replace(Replace(ConfInteger,"#1#",S),"#2#","true"),"#",Chr(34))
TextFile.WriteLine(S)
TextFile.Close
End Function
'///////////////////////////////////////////////////////////////////////////////////////////
'// ForceDirectories
Function ForceDirectories(Dirname)
Dim objFSO,Dir,X
Set objFSO=CreateObject("Scripting.FileSystemObject")
Dir=Dirname
If (Dir="") Then 
   Exit Function
   End If
If ((Len(Dir)<3) Or DirectoryExists(Dir)) Then 
   Exit Function
   End If
If Mid(Dir,1,Len(Dir))="\" Then 
   Dir=Mid(Dir,1,Len(Dir)-1) 
   End If
X=InStrRev(Dir,"\") 
ForceDirectories(Mid(Dir,1,X-1))
CreateDirectory(Dir)
End Function
'///////////////////////////////////////////////////////////////////////////////////////////